[network/smb4k] /: Change the word "package" to "packet" in the context of WOL

Alexander Reinholdt null at kde.org
Thu May 19 05:16:38 BST 2022


Git commit fe506b83a456ff5acf1e8f14a0ae2d6e5b183c9a by Alexander Reinholdt, on behalf of Shinjo Park.
Committed on 19/05/2022 at 04:04.
Pushed by areinholdt into branch 'master'.

Change the word "package" to "packet" in the context of WOL

The usage of work "package" may confuse some translators, as they may
not aware that the "package" here is network packet. This changes the
occurrence of "package" to "packet" to clarify this.

M  +2    -2    core/smb4k.kcfg
M  +1    -1    core/smb4kclient.cpp
M  +2    -2    core/smb4kcustomoptions.cpp
M  +8    -8    core/smb4kcustomoptions.h
M  +66   -66   core/smb4kcustomoptionsmanager_p.cpp
M  +1    -1    core/smb4kglobal.h
M  +4    -4    doc/index.docbook
M  +44   -44   smb4k/smb4kconfigpagecustomoptions.cpp
M  +1    -1    smb4k/smb4kconfigpagecustomoptions.h

https://invent.kde.org/network/smb4k/commit/fe506b83a456ff5acf1e8f14a0ae2d6e5b183c9a

diff --git a/core/smb4k.kcfg b/core/smb4k.kcfg
index 7294492f..b9867655 100644
--- a/core/smb4k.kcfg
+++ b/core/smb4k.kcfg
@@ -232,12 +232,12 @@
         </entry>
         <entry name="EnableWakeOnLAN" type="Bool">
             <label>Enable Wake-On-LAN features</label>
-            <whatsthis>Wake-on-LAN (WOL) is an ethernet computer networking standard that allows a computer to be turned on or woken up by a network message. Smb4K uses a magic package send via a UDP socket to wake up remote servers. If you want to take advantage of the Wake-On-LAN feature, you need to enable this option.</whatsthis>
+            <whatsthis>Wake-on-LAN (WOL) is an ethernet computer networking standard that allows a computer to be turned on or woken up by a network message. Smb4K uses a magic packet send via a UDP socket to wake up remote servers. If you want to take advantage of the Wake-On-LAN feature, you need to enable this option.</whatsthis>
             <default>false</default>
         </entry>
         <entry name="WakeOnLANWaitingTime" type="Int">
             <label>Waiting time:</label>
-            <whatsthis>This is the waiting time in seconds between the sending of the magic Wake-On-LAN packages and the scanning of the network neighborhood or the mounting of a share.</whatsthis>
+            <whatsthis>This is the waiting time in seconds between the sending of the magic Wake-On-LAN packets and the scanning of the network neighborhood or the mounting of a share.</whatsthis>
             <min>0</min>
             <max>60</max>
             <default>5</default>
diff --git a/core/smb4kclient.cpp b/core/smb4kclient.cpp
index 90a71001..27b47df1 100644
--- a/core/smb4kclient.cpp
+++ b/core/smb4kclient.cpp
@@ -80,7 +80,7 @@ void Smb4KClient::abort()
 void Smb4KClient::lookupDomains()
 {
     //
-    // Send Wakeup-On-LAN packages
+    // Send Wakeup-On-LAN packets
     //
     if (Smb4KSettings::enableWakeOnLAN()) {
         QList<OptionsPtr> wakeOnLanEntries = Smb4KCustomOptionsManager::self()->wakeOnLanEntries();
diff --git a/core/smb4kcustomoptions.cpp b/core/smb4kcustomoptions.cpp
index 5c976c37..d291a518 100644
--- a/core/smb4kcustomoptions.cpp
+++ b/core/smb4kcustomoptions.cpp
@@ -861,12 +861,12 @@ bool Smb4KCustomOptions::hasOptions(bool withoutRemountOnce) const
         return true;
     }
 
-    // Send WOL packages before first scan
+    // Send WOL packets before first scan
     if (d->wakeOnLanBeforeFirstScan) {
         return true;
     }
 
-    // Send WOL packages before mount
+    // Send WOL packets before mount
     if (d->wakeOnLanBeforeMount) {
         return true;
     }
diff --git a/core/smb4kcustomoptions.h b/core/smb4kcustomoptions.h
index f2c87c91..5bfe896f 100644
--- a/core/smb4kcustomoptions.h
+++ b/core/smb4kcustomoptions.h
@@ -553,39 +553,39 @@ public:
     QString macAddress() const;
 
     /**
-     * Set whether a magic WOL package should be send to the host that this
+     * Set whether a magic WOL packet should be send to the host that this
      * network item represents or where this network item is located before scanning
      * the entire network.
      *
-     * @param send              Boolean that determines if a magic WOL package
+     * @param send              Boolean that determines if a magic WOL packet
      *                          is to be sent.
      */
     void setWOLSendBeforeNetworkScan(bool send);
 
     /**
-     * Send a magic WOL package to the host that this network item represents
+     * Send a magic WOL packet to the host that this network item represents
      * or where this network item is located before scanning the entire network.
      *
-     * @returns TRUE if a magic WOL package should be send on first network
+     * @returns TRUE if a magic WOL packet should be send on first network
      * scan.
      */
     bool wolSendBeforeNetworkScan() const;
 
     /**
-     * Set whether a magic WOL package should be send to the host that this
+     * Set whether a magic WOL packet should be send to the host that this
      * network item represents or where this network item is located before a
      * mount attempt.
      *
-     * @param send              Boolean that determines if a magic WOL package
+     * @param send              Boolean that determines if a magic WOL packet
      *                          is to be sent.
      */
     void setWOLSendBeforeMount(bool send);
 
     /**
-     * Send a magic WOL package to the host that this network item represents
+     * Send a magic WOL packet to the host that this network item represents
      * or where this network item is located before a mount attempt.
      *
-     * @returns TRUE if a magic WOL package should be send on first network
+     * @returns TRUE if a magic WOL packet should be send on first network
      * scan.
      */
     bool wolSendBeforeMount() const;
diff --git a/core/smb4kglobal.h b/core/smb4kglobal.h
index fb10fd84..307e33de 100644
--- a/core/smb4kglobal.h
+++ b/core/smb4kglobal.h
@@ -56,7 +56,7 @@ namespace Smb4KGlobal
  * @enum LookupDomainMembers    Look up those servers that belong to a domain/workgroup
  * @enum LookupShares           Look up shares on a server
  * @enum LookupFiles            Look up files and directories within a share
- * @enum WakeUp                 Send magic Wake-On-LAN packages
+ * @enum WakeUp                 Send magic Wake-On-LAN packets
  * @enum PrintFile              Print a file
  * @enum NetworkSearch          Network search
  * @enum MountShare             Mount a share
diff --git a/doc/index.docbook b/doc/index.docbook
index 3315fd36..8d09d8cf 100644
--- a/doc/index.docbook
+++ b/doc/index.docbook
@@ -165,7 +165,7 @@
 
       <para>&smb4k; automatically scans the network neighborhood for active workgroups and domains on start-up, and presents them in the network neighborhood browser. For this purpose it uses &Samba;'s client library, <ulink url="https://en.wikipedia.org/wiki/Zero-configuration_networking#DNS-SD">DNS Service Discovery (DNS-SD)</ulink> and, optionally, <ulink url="https://en.wikipedia.org/wiki/WS-Discovery">Web Services Dynamic Discovery (WS-Discovery)</ulink>. The way &smb4k; browses the network neighborhood can be adjusted in the <link linkend="configuration_page_network_basic_settings_browse_settings"><guilabel>Network</guilabel> configuration page</link>.</para>
       <para>&smb4k; uses a traditional scan mode, where initially only workgroups and domains are looked up and scans are only made when necessary — &ie;, when you execute a network item. Due to the use of DNS-SD, you will most likely find a domain called <emphasis>LOCAL</emphasis> in the network neighborhood browser. This is the default local DNS domain used by services like <ulink url="https://en.wikipedia.org/wiki/Avahi_(software)">Avahi</ulink> and not an actual &Windows; domain. Opening a domain or workgroup item shows the servers belonging to it. If you want to access the shares of one of the servers, you must open the desired server.</para>
-      <para>There is also the possibility to wake up sleeping servers prior to scanning the network neighborhood (Wake-On-LAN). If this feature is enabled, &smb4k; sends a magic package to each server that is to be awakened, then waits the defined time until it starts to look up the workgroups and domains. The Wake-On-LAN setting can be turned on in the <link linkend="configuration_page_network_wake_on_lan_settings">configuration dialog</link>. The servers that should be awakened must be defined in the <link linkend="network_neighborhood_browser_defining_custom_options">Custom Options</link> dialog.</para>
+      <para>There is also the possibility to wake up sleeping servers prior to scanning the network neighborhood (Wake-On-LAN). If this feature is enabled, &smb4k; sends a magic packet to each server that is to be awakened, then waits the defined time until it starts to look up the workgroups and domains. The Wake-On-LAN setting can be turned on in the <link linkend="configuration_page_network_wake_on_lan_settings">configuration dialog</link>. The servers that should be awakened must be defined in the <link linkend="network_neighborhood_browser_defining_custom_options">Custom Options</link> dialog.</para>
     </sect2>
     
 <!--
@@ -487,7 +487,7 @@
       <sect3 id="network_neighborhood_browser_defining_custom_options_wol">
         <title>Wake-On-LAN Settings</title>
     
-        <para>To make the Wake-On-LAN feature work, you must provide the MAC address of the server you selected. Currently, &smb4k; has no way to determine the MAC address, so you need to find it on your own. Afterwards, you can define if &smb4k; should send a magic Wake-On-LAN package to the selected host before the network neighborhood is scanned and/or one of its shares is mounted.</para>
+        <para>To make the Wake-On-LAN feature work, you must provide the MAC address of the server you selected. Currently, &smb4k; has no way to determine the MAC address, so you need to find it on your own. Afterwards, you can define if &smb4k; should send a magic Wake-On-LAN packet to the selected host before the network neighborhood is scanned and/or one of its shares is mounted.</para>
       </sect3>
     </sect2>
 
@@ -1947,7 +1947,7 @@ ntlm auth = yes
             <menuchoice><guibutton>Enable Wake-On-LAN features</guibutton></menuchoice>
           </term>
           <listitem>
-            <para>Enable Wake-on-LAN (WOL) features. Wake-On-LAN is an ethernet computer networking standard that allows a computer to be turned on or woken up by a network message. Smb4K uses a magic package send via a UDP socket to wake up remote servers. If you want to take advantage of the Wake-On-LAN feature, you need to enable this option.</para>
+            <para>Enable Wake-on-LAN (WOL) features. Wake-On-LAN is an ethernet computer networking standard that allows a computer to be turned on or woken up by a network message. Smb4K uses a magic packet send via a UDP socket to wake up remote servers. If you want to take advantage of the Wake-On-LAN feature, you need to enable this option.</para>
             <para>Default: not selected</para>
             <variablelist>
               <varlistentry>
@@ -1955,7 +1955,7 @@ ntlm auth = yes
                   <menuchoice><guilabel>Waiting time</guilabel></menuchoice>
                 </term>
                 <listitem>
-                  <para>This is the waiting time in seconds between the sending of the magic Wake-On-LAN packages and the scanning of the network neighborhood or the mounting of a share.</para>
+                  <para>This is the waiting time in seconds between the sending of the magic Wake-On-LAN packets and the scanning of the network neighborhood or the mounting of a share.</para>
                   <para>Default: 5 s</para>
                 </listitem>
               </varlistentry>
diff --git a/smb4k/smb4kconfigpagecustomoptions.h b/smb4k/smb4kconfigpagecustomoptions.h
index 653ff2db..99e000a0 100644
--- a/smb4k/smb4kconfigpagecustomoptions.h
+++ b/smb4k/smb4kconfigpagecustomoptions.h
@@ -142,7 +142,7 @@ protected Q_SLOTS:
     void slotEntryChanged();
 
     /**
-     * Enable the options for sending Wake-On-LAN magic packages, if the MAC
+     * Enable the options for sending Wake-On-LAN magic packets, if the MAC
      * address was entered correctly.
      */
     void slotEnableWOLFeatures(const QString &mac_address);


More information about the kde-doc-english mailing list
diff --git a/core/smb4kcustomoptionsmanager_p.cpp b/core/smb4kcustomoptionsmanager_p.cpp
index cf6a3601..a672d58f 100644
--- a/core/smb4kcustomoptionsmanager_p.cpp
+++ b/core/smb4kcustomoptionsmanager_p.cpp
@@ -483,21 +483,21 @@ void Smb4KCustomOptionsDialog::setupView()
     QGroupBox *wakeOnLANActionsBox = new QGroupBox(i18n("Actions"), wakeOnLanTab);
     QVBoxLayout *wakeOnLANActionsBoxLayout = new QVBoxLayout(wakeOnLANActionsBox);
 
-    // Send magic package before network scan
-    QCheckBox *sendPackageBeforeScan = new QCheckBox(i18n("Send magic package before scanning the network neighborhood"), wakeOnLANActionsBox);
-    sendPackageBeforeScan->setObjectName("SendPackageBeforeScan");
+    // Send magic packet before network scan
+    QCheckBox *sendPacketBeforeScan = new QCheckBox(i18n("Send magic packet before scanning the network neighborhood"), wakeOnLANActionsBox);
+    sendPacketBeforeScan->setObjectName("SendPacketBeforeScan");
 
-    connect(sendPackageBeforeScan, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
+    connect(sendPacketBeforeScan, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeScan, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeScan, 0);
 
-    // Send magic package before mount
-    QCheckBox *sendPackageBeforeMount = new QCheckBox(i18n("Send magic package before mounting a share"), wakeOnLanTab);
-    sendPackageBeforeMount->setObjectName("SendPackageBeforeMount");
+    // Send magic packet before mount
+    QCheckBox *sendPacketBeforeMount = new QCheckBox(i18n("Send magic packet before mounting a share"), wakeOnLanTab);
+    sendPacketBeforeMount->setObjectName("SendPacketBeforeMount");
 
-    connect(sendPackageBeforeMount, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
+    connect(sendPacketBeforeMount, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeMount, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeMount, 0);
 
     wakeOnLanTabLayout->addWidget(wakeOnLANActionsBox, 0);
     wakeOnLanTabLayout->addStretch(100);
@@ -575,11 +575,11 @@ void Smb4KCustomOptionsDialog::setupView()
         // MAC address
         macAddress->setText(m_options->macAddress());
 
-        // Send magic package before scan
-        sendPackageBeforeScan->setChecked(m_options->wolSendBeforeNetworkScan());
+        // Send magic packet before scan
+        sendPacketBeforeScan->setChecked(m_options->wolSendBeforeNetworkScan());
 
-        // Send magic package before mount
-        sendPackageBeforeMount->setChecked(m_options->wolSendBeforeMount());
+        // Send magic packet before mount
+        sendPacketBeforeMount->setChecked(m_options->wolSendBeforeMount());
     } else {
         setDefaultValues();
     }
@@ -827,21 +827,21 @@ void Smb4KCustomOptionsDialog::setupView()
     QGroupBox *wakeOnLANActionsBox = new QGroupBox(i18n("Actions"), wakeOnLanTab);
     QVBoxLayout *wakeOnLANActionsBoxLayout = new QVBoxLayout(wakeOnLANActionsBox);
 
-    // Send magic package before network scan
-    QCheckBox *sendPackageBeforeScan = new QCheckBox(i18n("Send magic package before scanning the network neighborhood"), wakeOnLANActionsBox);
-    sendPackageBeforeScan->setObjectName("SendPackageBeforeScan");
+    // Send magic packet before network scan
+    QCheckBox *sendPacketBeforeScan = new QCheckBox(i18n("Send magic packet before scanning the network neighborhood"), wakeOnLANActionsBox);
+    sendPacketBeforeScan->setObjectName("SendPacketBeforeScan");
 
-    connect(sendPackageBeforeScan, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
+    connect(sendPacketBeforeScan, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeScan, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeScan, 0);
 
-    // Send magic package before mount
-    QCheckBox *sendPackageBeforeMount = new QCheckBox(i18n("Send magic package before mounting a share"), wakeOnLanTab);
-    sendPackageBeforeMount->setObjectName("SendPackageBeforeMount");
+    // Send magic packet before mount
+    QCheckBox *sendPacketBeforeMount = new QCheckBox(i18n("Send magic packet before mounting a share"), wakeOnLanTab);
+    sendPacketBeforeMount->setObjectName("SendPacketBeforeMount");
 
-    connect(sendPackageBeforeMount, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
+    connect(sendPacketBeforeMount, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeMount, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeMount, 0);
 
     wakeOnLanTabLayout->addWidget(wakeOnLANActionsBox, 0);
     wakeOnLanTabLayout->addStretch(100);
@@ -893,11 +893,11 @@ void Smb4KCustomOptionsDialog::setupView()
         // MAC address
         macAddress->setText(m_options->macAddress());
 
-        // Send magic package before scan
-        sendPackageBeforeScan->setChecked(m_options->wolSendBeforeNetworkScan());
+        // Send magic packet before scan
+        sendPacketBeforeScan->setChecked(m_options->wolSendBeforeNetworkScan());
 
-        // Send magic package before mount
-        sendPackageBeforeMount->setChecked(m_options->wolSendBeforeMount());
+        // Send magic packet before mount
+        sendPacketBeforeMount->setChecked(m_options->wolSendBeforeMount());
     } else {
         setDefaultValues();
     }
@@ -1052,21 +1052,21 @@ void Smb4KCustomOptionsDialog::setupView()
     QGroupBox *wakeOnLANActionsBox = new QGroupBox(i18n("Actions"), wakeOnLanTab);
     QVBoxLayout *wakeOnLANActionsBoxLayout = new QVBoxLayout(wakeOnLANActionsBox);
 
-    // Send magic package before network scan
-    QCheckBox *sendPackageBeforeScan = new QCheckBox(i18n("Send magic package before scanning the network neighborhood"), wakeOnLANActionsBox);
-    sendPackageBeforeScan->setObjectName("SendPackageBeforeScan");
+    // Send magic packet before network scan
+    QCheckBox *sendPacketBeforeScan = new QCheckBox(i18n("Send magic packet before scanning the network neighborhood"), wakeOnLANActionsBox);
+    sendPacketBeforeScan->setObjectName("SendPacketBeforeScan");
 
-    connect(sendPackageBeforeScan, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
+    connect(sendPacketBeforeScan, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeScan, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeScan, 0);
 
-    // Send magic package before mount
-    QCheckBox *sendPackageBeforeMount = new QCheckBox(i18n("Send magic package before mounting a share"), wakeOnLanTab);
-    sendPackageBeforeMount->setObjectName("SendPackageBeforeMount");
+    // Send magic packet before mount
+    QCheckBox *sendPacketBeforeMount = new QCheckBox(i18n("Send magic packet before mounting a share"), wakeOnLanTab);
+    sendPacketBeforeMount->setObjectName("SendPacketBeforeMount");
 
-    connect(sendPackageBeforeMount, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
+    connect(sendPacketBeforeMount, SIGNAL(toggled(bool)), SLOT(slotCheckValues()));
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeMount, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeMount, 0);
 
     wakeOnLanTabLayout->addWidget(wakeOnLANActionsBox, 0);
     wakeOnLanTabLayout->addStretch(100);
@@ -1098,11 +1098,11 @@ void Smb4KCustomOptionsDialog::setupView()
         // MAC address
         macAddress->setText(m_options->macAddress());
 
-        // Send magic package before scan
-        sendPackageBeforeScan->setChecked(m_options->wolSendBeforeNetworkScan());
+        // Send magic packet before scan
+        sendPacketBeforeScan->setChecked(m_options->wolSendBeforeNetworkScan());
 
-        // Send magic package before mount
-        sendPackageBeforeMount->setChecked(m_options->wolSendBeforeMount());
+        // Send magic packet before mount
+        sendPacketBeforeMount->setChecked(m_options->wolSendBeforeMount());
     } else {
         setDefaultValues();
     }
@@ -1392,18 +1392,18 @@ bool Smb4KCustomOptionsDialog::checkDefaultValues()
             }
         }
 
-        QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+        QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-        if (sendPackageBeforeScan) {
-            if (sendPackageBeforeScan->isChecked()) {
+        if (sendPacketBeforeScan) {
+            if (sendPacketBeforeScan->isChecked()) {
                 return false;
             }
         }
 
-        QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+        QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-        if (sendPackageBeforeMount) {
-            if (sendPackageBeforeMount->isChecked()) {
+        if (sendPacketBeforeMount) {
+            if (sendPacketBeforeMount->isChecked()) {
                 return false;
             }
         }
@@ -1638,16 +1638,16 @@ void Smb4KCustomOptionsDialog::setDefaultValues()
             macAddress->setInputMask("HH:HH:HH:HH:HH:HH;_");
         }
 
-        QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+        QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-        if (sendPackageBeforeScan) {
-            sendPackageBeforeScan->setChecked(false);
+        if (sendPacketBeforeScan) {
+            sendPacketBeforeScan->setChecked(false);
         }
 
-        QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+        QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-        if (sendPackageBeforeMount) {
-            sendPackageBeforeMount->setChecked(false);
+        if (sendPacketBeforeMount) {
+            sendPacketBeforeMount->setChecked(false);
         }
     }
 }
@@ -1908,16 +1908,16 @@ void Smb4KCustomOptionsDialog::saveValues()
             m_options->setMACAddress(macAddress->text());
         }
 
-        QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+        QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-        if (sendPackageBeforeScan) {
-            m_options->setWOLSendBeforeNetworkScan(sendPackageBeforeScan->isChecked());
+        if (sendPacketBeforeScan) {
+            m_options->setWOLSendBeforeNetworkScan(sendPacketBeforeScan->isChecked());
         }
 
-        QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+        QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-        if (sendPackageBeforeMount) {
-            m_options->setWOLSendBeforeMount(sendPackageBeforeMount->isChecked());
+        if (sendPacketBeforeMount) {
+            m_options->setWOLSendBeforeMount(sendPacketBeforeMount->isChecked());
         }
     }
 
@@ -1956,16 +1956,16 @@ void Smb4KCustomOptionsDialog::slotEnableWOLFeatures(const QString &mac)
 {
     QRegExp exp("..\\:..\\:..\\:..\\:..\\:..");
 
-    QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+    QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-    if (sendPackageBeforeScan) {
-        sendPackageBeforeScan->setEnabled(m_options->type() == Host && exp.exactMatch(mac));
+    if (sendPacketBeforeScan) {
+        sendPacketBeforeScan->setEnabled(m_options->type() == Host && exp.exactMatch(mac));
     }
 
-    QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+    QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-    if (sendPackageBeforeMount) {
-        sendPackageBeforeMount->setEnabled(m_options->type() == Host && exp.exactMatch(mac));
+    if (sendPacketBeforeMount) {
+        sendPacketBeforeMount->setEnabled(m_options->type() == Host && exp.exactMatch(mac));
     }
 }
 
diff --git a/smb4k/smb4kconfigpagecustomoptions.cpp b/smb4k/smb4kconfigpagecustomoptions.cpp
index 1bbd0d88..9604468c 100644
--- a/smb4k/smb4kconfigpagecustomoptions.cpp
+++ b/smb4k/smb4kconfigpagecustomoptions.cpp
@@ -248,17 +248,17 @@ Smb4KConfigPageCustomOptions::Smb4KConfigPageCustomOptions(QWidget *parent)
     QGroupBox *wakeOnLANActionsBox = new QGroupBox(i18n("Actions"), wakeOnLanTab);
     QVBoxLayout *wakeOnLANActionsBoxLayout = new QVBoxLayout(wakeOnLANActionsBox);
 
-    // Send magic package before network scan
-    QCheckBox *sendPackageBeforeScan = new QCheckBox(i18n("Send magic package before scanning the network neighborhood"), wakeOnLANActionsBox);
-    sendPackageBeforeScan->setObjectName("SendPackageBeforeScan");
+    // Send magic packet before network scan
+    QCheckBox *sendPacketBeforeScan = new QCheckBox(i18n("Send magic packet before scanning the network neighborhood"), wakeOnLANActionsBox);
+    sendPacketBeforeScan->setObjectName("SendPacketBeforeScan");
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeScan, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeScan, 0);
 
-    // Send magic package before mount
-    QCheckBox *sendPackageBeforeMount = new QCheckBox(i18n("Send magic package before mounting a share"), wakeOnLanTab);
-    sendPackageBeforeMount->setObjectName("SendPackageBeforeMount");
+    // Send magic packet before mount
+    QCheckBox *sendPacketBeforeMount = new QCheckBox(i18n("Send magic packet before mounting a share"), wakeOnLanTab);
+    sendPacketBeforeMount->setObjectName("SendPacketBeforeMount");
 
-    wakeOnLANActionsBoxLayout->addWidget(sendPackageBeforeMount, 0);
+    wakeOnLANActionsBoxLayout->addWidget(sendPacketBeforeMount, 0);
 
     wakeOnLanTabLayout->addWidget(wakeOnLANActionsBox, 0);
     wakeOnLanTabLayout->addStretch(100);
@@ -876,23 +876,23 @@ void Smb4KConfigPageCustomOptions::clearEditors()
     }
 
     //
     // Wake-On-Lan: send package before scan
     //
-    QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+    QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-    if (sendPackageBeforeScan) {
-        disconnect(sendPackageBeforeScan, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
-        sendPackageBeforeScan->setChecked(false);
+    if (sendPacketBeforeScan) {
+        disconnect(sendPacketBeforeScan, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
+        sendPacketBeforeScan->setChecked(false);
     }
 
     //
     // Wake-On-Lan: Send package before mount
     //
-    QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+    QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-    if (sendPackageBeforeMount) {
-        disconnect(sendPackageBeforeMount, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
-        sendPackageBeforeMount->setChecked(false);
+    if (sendPacketBeforeMount) {
+        disconnect(sendPacketBeforeMount, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
+        sendPacketBeforeMount->setChecked(false);
     }
 
     //
@@ -1177,23 +1177,23 @@ void Smb4KConfigPageCustomOptions::populateEditors()
     }
 
     //
     // Wake-On-Lan: Send package before scan
     //
-    QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+    QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-    if (sendPackageBeforeScan) {
-        sendPackageBeforeScan->setChecked(m_currentOptions->wolSendBeforeNetworkScan());
-        connect(sendPackageBeforeScan, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
+    if (sendPacketBeforeScan) {
+        sendPacketBeforeScan->setChecked(m_currentOptions->wolSendBeforeNetworkScan());
+        connect(sendPacketBeforeScan, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
     }
 
     //
     // Wake-On-Lan: Send package before mount
     //
-    QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+    QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-    if (sendPackageBeforeMount) {
-        sendPackageBeforeMount->setChecked(m_currentOptions->wolSendBeforeMount());
-        connect(sendPackageBeforeMount, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
+    if (sendPacketBeforeMount) {
+        sendPacketBeforeMount->setChecked(m_currentOptions->wolSendBeforeMount());
+        connect(sendPacketBeforeMount, SIGNAL(toggled(bool)), this, SLOT(slotEntryChanged()));
     }
 
     //
@@ -1484,21 +1484,21 @@ void Smb4KConfigPageCustomOptions::commitChanges()
     }
 
     //
     // Wake-On-Lan: Send package before scan
     //
-    QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+    QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-    if (sendPackageBeforeScan) {
-        m_currentOptions->setWOLSendBeforeNetworkScan(sendPackageBeforeScan->isChecked());
+    if (sendPacketBeforeScan) {
+        m_currentOptions->setWOLSendBeforeNetworkScan(sendPacketBeforeScan->isChecked());
     }
 
     //
     // Wake-On-Lan: Send package before mount
     //
-    QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+    QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-    if (sendPackageBeforeMount) {
-        m_currentOptions->setWOLSendBeforeMount(sendPackageBeforeMount->isChecked());
+    if (sendPacketBeforeMount) {
+        m_currentOptions->setWOLSendBeforeMount(sendPacketBeforeMount->isChecked());
     }
 
     //
@@ -1684,21 +1684,21 @@ void Smb4KConfigPageCustomOptions::slotEnableWOLFeatures(const QString &mac_addr
     QRegExp exp("..\\:..\\:..\\:..\\:..\\:..");
 
     //
     // Wake-On_lan: send package before scan
     //
-    QCheckBox *sendPackageBeforeScan = findChild<QCheckBox *>("SendPackageBeforeScan");
+    QCheckBox *sendPacketBeforeScan = findChild<QCheckBox *>("SendPacketBeforeScan");
 
-    if (sendPackageBeforeScan) {
-        sendPackageBeforeScan->setEnabled(exp.exactMatch(mac_address));
+    if (sendPacketBeforeScan) {
+        sendPacketBeforeScan->setEnabled(exp.exactMatch(mac_address));
     }
 
     //
     // Wake-On-Lan: send package before mount
     //
-    QCheckBox *sendPackageBeforeMount = findChild<QCheckBox *>("SendPackageBeforeMount");
+    QCheckBox *sendPacketBeforeMount = findChild<QCheckBox *>("SendPacketBeforeMount");
 
-    if (sendPackageBeforeMount) {
-        sendPackageBeforeMount->setEnabled(exp.exactMatch(mac_address));
+    if (sendPacketBeforeMount) {
+        sendPacketBeforeMount->setEnabled(exp.exactMatch(mac_address));
     }
 }
 
@@ -876,23 +876,23 @@ void Smb4KConfigPageCustomOptions::clearEditors()
 
     //
-    // Wake-On-Lan: send package before scan
+    // Wake-On-Lan: send packet before scan
     //
@@ -876,23 +876,23 @@ void Smb4KConfigPageCustomOptions::clearEditors()
 
     //
-    // Wake-On-Lan: Send package before mount
+    // Wake-On-Lan: Send packet before mount
     //
@@ -1177,23 +1177,23 @@ void Smb4KConfigPageCustomOptions::populateEditors()
 
     //
-    // Wake-On-Lan: Send package before scan
+    // Wake-On-Lan: Send packet before scan
     //
@@ -1177,23 +1177,23 @@ void Smb4KConfigPageCustomOptions::populateEditors()
 
     //
-    // Wake-On-Lan: Send package before mount
+    // Wake-On-Lan: Send packet before mount
     //
@@ -1484,21 +1484,21 @@ void Smb4KConfigPageCustomOptions::commitChanges()
 
     //
-    // Wake-On-Lan: Send package before scan
+    // Wake-On-Lan: Send packet before scan
     //
@@ -1484,21 +1484,21 @@ void Smb4KConfigPageCustomOptions::commitChanges()
 
     //
-    // Wake-On-Lan: Send package before mount
+    // Wake-On-Lan: Send packet before mount
     //
@@ -1684,21 +1684,21 @@ void Smb4KConfigPageCustomOptions::slotEnableWOLFeatures(const QString &mac_addr
 
     //
-    // Wake-On_lan: send package before scan
+    // Wake-On_lan: send packet before scan
     //
@@ -1684,21 +1684,21 @@ void Smb4KConfigPageCustomOptions::slotEnableWOLFeatures(const QString &mac_addr
 
     //
-    // Wake-On-Lan: send package before mount
+    // Wake-On-Lan: send packet before mount
     //